;################################################################################
;#										#
;# chipbasic-M32 v0.93								#
;# single chip basic computer with ATmega32					#
;# copyright (c) 2006/2007 Joerg Wolfram (joerg@jcwolfram.de)			#
;#										#
;#										#
;# This program is free software; you can redistribute it and/or		#
;# modify it under the terms of the GNU General Public License as 		#
;# published by the Free Software Foundation; either version 3 of		#
;# the License, or (at your option) any later version.				#
;#										#
;# This library is distributed in the hope that it will be useful,		#
;# but WITHOUT ANY WARRANTY; without even the implied warranty of		#
;# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU		#
;# Lesser General Public License for more details.				#
;#										#
;# You should have received a copy of the GNU Lesser General Public		#
;# License along with this library; if not, write to the			#
;# Free Software Foundation, Inc., 59 Temple Place - Suite 330,			#
;# Boston, MA 02111-1307, USA.							#
;#										#
;################################################################################

.CSEG
.include	"/usr/local/include/avr/m32def.inc"
.include	"libdef.asm"			;register definitions
.def		vline_l = r8
.def		vline_h = r9

.equ		libmio_ram	= 0x060		;52 bytes libmio system RAM
.equ		bas_ram		= 0x094		;16 bytes basic system RAM
.equ		bas_inbuf	= 0x0a4		;36 bytes input buffer
.equ		bas_linebuf	= 0x0c8		;36 bytes line buffer
.equ		libmio_vram	= 0x0ec		;690 bytes of video RAM
.equ		mon_bpage	= 0x39e		;690 bytes backup page
.equ		varspace	= 0x650		;52 bytes basic variables
.equ		expar_ros	= 0x6ac		;40 bytes operand stack
.equ		bas_stacks	= 0x6ac		;80 bytes basic stacks
.equ		libmio_sprites	= 0x6fc		;24 bytes sprites
.equ		bas_array	= 0x714		;256 Bytes Array
.equ		stack		= 0x85f		;64 bytes stack


.include	"libmio/definitions.asm"
.include	"libeep/definitions.asm"
.include	"libi2c/definitions.asm"
.include	"macros.inc"

.set		bas_lines=51
.set		bas_stackdepth = 16
.set		bas_maxprog = 4

.org 0x0000
		rjmp	start
.org OC1Baddr	
		libmio_vint

start:		cli
		ldi	XL,0x00
		mov	byte0,XL
		ldi	XL,0x01
		mov	byte1,XL
		ldi	XL,HIGH(stack)
		out	SPH,XL
		ldi	XL,LOW(stack)
		out	SPL,XL

		libmio_init
		libi2c_init
		libmio_clrscr
		clr	ereg
		sei
		sts	libmio_kflags,byte0
		lds	XL,libmio_config	;config
		sbrc	XL,4			;autorun pin
loop:		jmp	menu_main		;editor
loop1:		call	mem_cpadr
loop2:		libmio_clrscr
		call	menu_runprog		;run program
		libmio_waitkey
		rjmp	start			;run again

.include	"modules/menu.asm"
.include	"modules/editor.asm"
.include	"modules/exparser.asm"
.include	"modules/interpreter.asm"
.include	"modules/tokenizer.asm"
.include	"modules/dflash.asm"
.include	"modules/monitor.asm"

.include	"libs.inc"



.org	0x1c00
libmio_ctable:
.include	"libmio/cchartable.inc"

.org	0x2b00
bas_programs:

;filename 1
.org	0x2e30
		.db "EMPTY FILE 1"

;filename 2
.org	0x3170
		.db "EMPTY FILE 2"

;filename 3
.org	0x34b0
		.db "EMPTY FILE 3"

;filename 4
.org	0x37f0
		.db "EMPTY FILE 4"

;---------------------------------------------------------------------------------
;start of nrww-section
;---------------------------------------------------------------------------------
.org	0x3800
.include	"modules/memory.asm"

.org	0x3900
.include	"libmio/keytables.inc"

.org	0x3a00
.include	"libmio/soundtables.inc"

.org	0x3b00
libmio_ectable:
.include	"libmio/mchartable.inc"
